==> pointpos_api-0.0.13.tar.gz: lib/api/purchase_order_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/purchase_order.dart';

part 'purchase_order_api.jretro.dart';

@GenApiClient()
class PurchaseOrderApi extends ApiClient with _$PurchaseOrderApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    PurchaseOrderApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Purchaseorder
    ///
    /// Create Purchaseorder
    @PostReq(path: "/purchase-order", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PurchaseOrder> createPurchaseorder(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() PurchaseOrder body
        ) {
        return super.createPurchaseorder(
        
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Purchaseorder By ID
    ///
    /// Delete Purchaseorder By ID
    @DeleteReq(path: "/purchase-order/:outletId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deletePurchaseorderByID(
            @PathParam("outletId") String outletId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deletePurchaseorderByID(
        outletId
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Get Purchaseorder List
    ///
    /// Get Purchaseorder  List
    @GetReq(path: "/purchase-order", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<PurchaseOrder>> findPurchaseorder(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findPurchaseorder(
        
        authorization, 
        
        xAPIKey
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Purchaseorder By ID
    ///
    /// Get Purchaseorder By ID
    @GetReq(path: "/purchase-order/:outletId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PurchaseOrder> getPurchaseorderByID(
            @PathParam("outletId") String outletId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.getPurchaseorderByID(
        outletId
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Update Purchaseorder By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/purchase-order/:outletId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PurchaseOrder> updatePurchaseorderByID(
            @PathParam("outletId") String outletId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() PurchaseOrder body
        ) {
        return super.updatePurchaseorderByID(
        outletId
        ,
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }


}

==> pointpos_api-0.0.16.tar.gz: lib/api/purchase_order_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/purchase_order.dart';

part 'purchase_order_api.jretro.dart';

@GenApiClient()
class PurchaseOrderApi extends ApiClient with _$PurchaseOrderApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    PurchaseOrderApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Purchaseorder
    ///
    /// Create Purchaseorder
    @PostReq(path: "/purchase-order", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PurchaseOrder> createPurchaseorder(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() PurchaseOrder body
        ) {
        return super.createPurchaseorder(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Purchaseorder By ID
    ///
    /// Delete Purchaseorder By ID
    @DeleteReq(path: "/purchase-order/:outletId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deletePurchaseorderByID(
            @PathParam("outletId") String outletId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deletePurchaseorderByID(
        outletId
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Purchaseorder List
    ///
    /// Get Purchaseorder  List
    @GetReq(path: "/purchase-order", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<PurchaseOrder>> findPurchaseorder(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findPurchaseorder(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Purchaseorder By ID
    ///
    /// Get Purchaseorder By ID
    @GetReq(path: "/purchase-order/:outletId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PurchaseOrder> getPurchaseorderByID(
            @PathParam("outletId") String outletId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getPurchaseorderByID(
        outletId
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Purchaseorder By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/purchase-order/:outletId", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<PurchaseOrder> updatePurchaseorderByID(
            @PathParam("outletId") String outletId
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() PurchaseOrder body
        ) {
        return super.updatePurchaseorderByID(
        outletId
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
